#ifndef AlarmListDialog_h
#define AlarmListDialog_h

// $Id: AlarmListDialog.h,v 1.14 2014/02/10 10:07:45 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

/*!
\file AlarmListDialog.h
\brief Edit/create alarms
\author Hugo Pereira
\version $Revision: 1.14 $
\date $Date: 2014/02/10 10:07:45 $
*/

#include "AlarmModel.h"
#include "CustomDialog.h"

#include <QPushButton>
#include <QAction>

class TreeView;

namespace Clock
{
    //! Edit/create alarms
    class AlarmListDialog: public CustomDialog
    {


        //! Qt meta object declaration
        Q_OBJECT

        public:

        //! constructor
        AlarmListDialog( QWidget*, const Alarm::List& = Alarm::List() );

        //! destructor
        virtual ~AlarmListDialog( void )
        {}

        //! alarm list
        void setList( const Alarm::List& );

        //! alarm list
        Alarm::List list( void ) const;

        protected Q_SLOTS:

        //! toggle alarm enabled state
        void _toggle( const QModelIndex& );

        //! update buttons
        void _updateButtons( void );

        //! add a value
        void _add( void );

        //! add a value
        void _edit( void );

        //! remove a value
        void _remove( void );

        private:

        //! list
        TreeView& _list( void ) const
        { return *list_; }

        //! model
        AlarmModel model_;

        //! alarm list
        TreeView* list_;

        //! edit button
        QPushButton* edit_;

        //! remove button
        QPushButton* remove_;

        //! remove action
        QAction* removeAction_;

    };

}

#endif
