#ifndef ClockWidget_h
#define ClockWidget_h
// $Id: ClockWidget.h,v 1.29 2014/02/20 17:55:31 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "AlarmList.h"
#include "MainWindow.h"

#include <QAction>
#include <QBasicTimer>
#include <QTimerEvent>

//! clock widgets
namespace Clock
{


    //! transparent clock widget
    class ClockWidget: public MainWindow
    {

        //! Qt meta object declaration
        Q_OBJECT

        public:

        //! constructor
        ClockWidget( QWidget *parent = 0 );

        protected:

        //! context menu
        virtual void _installContextMenuActions( BaseContextMenu* );

        //!@name event handlers
        //@{

        //! enter event
        virtual void enterEvent( QEvent* );

        //! timer event, to toggle repaint
        virtual void timerEvent( QTimerEvent* );

        //! paint event handler
        void _paint( QPaintDevice&, const QRect& );

        //@}

        //! hour color
        const QColor& _hourColor( void ) const
        { return hourColor_; }

        //! hour color
        void _setHourColor( QColor value )
        { hourColor_ = value; }

        //! minutes color
        const QColor& _minuteColor( void ) const
        { return minuteColor_; }

        //! minute color
        void _setMinuteColor( QColor value )
        { minuteColor_ = value; }

        //! seconds color
        const QColor& _secondColor( void ) const
        { return secondColor_; }

        //! second color
        void _setSecondColor( QColor value )
        { secondColor_ = value; }

        protected Q_SLOTS:

        //! repeat
        void _setRepeat( const Alarm& );

        //! repeat
        void _unsetRepeat( const Alarm& );

        //! configuration
        virtual void _configuration( void );

        //! update configuration
        virtual void _updateConfiguration( void );

        //! hours
        virtual void _toggleHourTicks( bool );

        //! minutes
        virtual void _toggleMinuteTicks( bool );

        //! seconds
        virtual void _toggleSeconds( bool );

        //! seconds
        virtual void _toggleDate( bool );

        //! configure alarms
        virtual void _configureAlarms( void );

        //! adjust time
        virtual void _adjustTime( void );

        //! toggle inverse colors
        virtual void _toggleInverseColors( bool );

        private:

        //! install actions
        void _installActions( void );

        //! check alarms
        void _checkAlarms( void );

        //! hand
        static QPolygonF _hand( const int& width, const int& length );

        //! redraw timer
        QBasicTimer timer_;

        //! alarm timer
        /*!
        it is kept separated from the redraw because it only needs to run
        when there are alarms enabled.
        */
        QBasicTimer alarmTimer_;

        //!@name actions
        //@{

        //! ticks
        QAction* showHourTicksAction_;

        //! ticks
        QAction* showMinuteTicksAction_;

        //! seconds
        QAction* showSecondsAction_;

        //! date
        QAction* showDateAction_;

        //! alarms action
        QAction* configureAlarmsAction_;

        //! adjust time action
        QAction* adjustTimeAction_;

        //@}

        //!@name properties
        //@{

        //! hours color
        QColor hourColor_;

        //! minutes color
        QColor minuteColor_;

        //! seconds color
        QColor secondColor_;

        //! hour delay
        int delay_;

        //@}

        //! alarms
        AlarmList alarms_;
    };

}

#endif
