/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "DiskLoadWrapper.h"
#include "DiskMenu.h"
#include "DiskMenu.moc"
#include "IconEngine.h"


namespace Disk
{
    //_____________________________________________________
    DiskMenu::DiskMenu( const QString& name, QWidget* parent ):
        QMenu( name, parent ),
        Counter( "DiskMenu" ),
        kernel_( Main::Linux26 )
    {

        Debug::Throw( "DiskMenu::DiskMenu.\n" );
        connect( this, SIGNAL(triggered(QAction*)), SLOT(_select(QAction*)) );
        connect( this, SIGNAL(aboutToShow()), SLOT(_update()) );

        actionGroup_ = new QActionGroup( this );
        actionGroup_->setExclusive( true );

    }

    //_____________________________________________________
    void DiskMenu::_select( QAction* action )
    {

        Debug::Throw( "DiskMenu::_select.\n" );
        ActionMap::const_iterator iter( actions_.find( action ) );
        if( iter != actions_.end() )
        {
            device_ = iter.value();
            emit deviceSelected( device_ );
        }

        return;
    }

    //_____________________________________________________
    void DiskMenu::_update( void )
    {
        Debug::Throw( "DiskMenu::_update.\n" );

        // clear
        clear();
        actions_.clear();

        DiskLoadWrapper load;
        load.setKernelVersion( kernel_ );
        load.get().update();

        DiskLoad::DeviceSet devices( load.get().devices() );
        if( devices.empty() ) devices.insert( device_ );
        for( DiskLoad::DeviceSet::iterator iter = devices.begin(); iter != devices.end(); ++iter )
        {

            QAction* action = addAction( *iter );
            actionGroup_->addAction( action );
            action->setCheckable( true );
            action->setChecked( device_ == *iter );

            actions_.insert( action, *iter );

        }

        return;

    }
}
