// $Id: ApplicationType.cpp,v 1.13 2014/02/18 15:15:56 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/


#include "ApplicationType.h"

//____________________________________________
ApplicationType::Map& ApplicationType::names( void )
{
  static Map map;
  if( map.empty() )
  {
    map.insert( AppNone, QObject::tr( "unknown" ) );
    map.insert( AppAcpi, QObject::tr( "Battery Monitor" ) );
    map.insert( AppCalendar, QObject::tr( "Transparent Calendar" ) );
    map.insert( AppClock, QObject::tr( "Transparent Clock" ) );
    map.insert( AppCpu, QObject::tr( "Cpu Monitor" ) );
    map.insert( AppDisk, QObject::tr( "Disk Monitor" ) );
    map.insert( AppMemory, QObject::tr( "Memory Monitor" ) );
    map.insert( AppNetwork, QObject::tr( "Network Monitor" ) );
    map.insert( AppSummary, QObject::tr( "System Monitor Summary" ) );
    map.insert( AppTemperature, QObject::tr( "Temperature Monitor" ) );

  }
  return map;

}

//____________________________________________
ApplicationType::Map& ApplicationType::iconNames( void )
{
  static Map map;
  if( map.empty() )
  {
    map.insert( AppNone, ":/transparency.png");
    map.insert( AppAcpi, ":transparent-acpi.png");
    map.insert( AppCalendar, ":/transparent-calendar.png");
    map.insert( AppClock, ":/transparent-clock.png");
    map.insert( AppCpu, ":/transparent-cpu-load.png");
    map.insert( AppDisk, ":/transparent-disk-load.png");
    map.insert( AppMemory, ":/transparent-memory-load.png");
    map.insert( AppNetwork, ":/transparent-network-load.png");
    map.insert( AppSummary, ":/transparent-system-monitor.png");
    map.insert( AppTemperature, ":/transparency.png");

  }
  return map;

}

//____________________________________________
ApplicationType::Set::Set( const CommandLineParser& parser )
{

    bool all( parser.hasFlag( "--all" ) );
    if( all || parser.hasFlag( "--acpi" ) ) insert( ApplicationType::AppAcpi );
    if( all || parser.hasFlag( "--calendar" ) ) insert( ApplicationType::AppCalendar );
    if( all || parser.hasFlag( "--clock" ) ) insert( ApplicationType::AppClock );
    if( all || parser.hasFlag( "--cpu" ) ) insert( ApplicationType::AppCpu );
    if( all || parser.hasFlag( "--disk" ) ) insert( ApplicationType::AppDisk );
    if( all || parser.hasFlag( "--memory" ) ) insert( ApplicationType::AppMemory );
    if( all || parser.hasFlag( "--network" ) ) insert( ApplicationType::AppNetwork );
    if( all || parser.hasFlag( "--summary" ) ) insert( ApplicationType::AppSummary );
    if( all || parser.hasFlag( "--temperature" ) ) insert( ApplicationType::AppTemperature );

}

//____________________________________________
ApplicationType::Set::Set( unsigned int mask )
{
    if( mask & AppAcpi ) insert( ApplicationType::AppAcpi );
    if( mask & AppCalendar ) insert( ApplicationType::AppCalendar );
    if( mask & AppClock ) insert( ApplicationType::AppClock );
    if( mask & AppCpu ) insert( ApplicationType::AppCpu );
    if( mask & AppDisk ) insert( ApplicationType::AppDisk );
    if( mask & AppMemory ) insert( ApplicationType::AppMemory );
    if( mask & AppNetwork ) insert( ApplicationType::AppNetwork );
    if( mask & AppSummary ) insert( ApplicationType::AppSummary );
    if( mask & AppTemperature ) insert( ApplicationType::AppTemperature );

}

//______________________________________
ApplicationType::Set::operator unsigned int () const
{
    unsigned int out( ApplicationType::AppNone );
    for( const_iterator iter = begin(); iter != end(); ++iter )
    { out |= iter->type(); }

    return out;
}
