// $Id: transparency.cpp,v 1.39 2014/02/18 15:15:56 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "ApplicationType.h"
#include "File.h"
#include "TransparencyApplication.h"
#include "Util.h"
#include "XmlOptions.h"

#include <QSet>

#include <unistd.h>

//__________________________________________
int run( ApplicationType type, int argc, char *argv[] );

//__________________________________________
//! main function
int main(int argc, char *argv[])
{

    // load possible command file
    CommandLineArguments arguments( argc, argv );
    CommandLineParser parser( TransparencyApplication( arguments ).commandLineParser( arguments, false ) );

    if( parser.hasFlag( "--help" ) )
    {
        TransparencyApplication( arguments ).usage();
        return 0;
    }

    // load types from arguments
    ApplicationType::Set types( parser );

    // try restore previous session if empty
    const File file( File( ".transparentrc" ).addPath( Util::home() ) );
    if( types.empty() )
    {

        // read from file
        if( file.exists() )
        {
            XmlOptions::setFile( file );
            XmlOptions::read();
            types = ApplicationType::Set( XmlOptions::get().get<unsigned int>( "PREVIOUS_SESSION" ) );
        }

        if( !types.empty() )
        {

            Debug::Throw(0) << "transparency - restoring previous session." << endl;

        } else {

            TransparencyApplication( arguments ).usage();

        }

    } else {

        if( parser.hasFlag( "--append" ) )
        {

            // read from file
            if( file.exists() ) XmlOptions::read();

            unsigned int flags( XmlOptions::get().contains( "PREVIOUS_SESSION" ) ? XmlOptions::get().get<unsigned int>( "PREVIOUS_SESSION" ) : ApplicationType::AppNone );
            flags |= types;
            XmlOptions::get().set<unsigned int>( "PREVIOUS_SESSION", flags );

        } else  XmlOptions::get().set<unsigned int>( "PREVIOUS_SESSION", types );

        // write
        XmlOptions::write();

    }

    // do nothing if still empty
    if( types.empty() ) return 0;

    // clear options
    // XmlOptions::get().clear();

    // fork types if more than one argument
    QSet<ApplicationType>::iterator iter( types.begin() );
    ApplicationType type = *iter;
    ++iter;

    for( ; iter != types.end(); ++iter )
    {

        if( !fork() ) {
            type = *iter;
            break;
        }

    }

    return run( type, argc, argv );

}
