#ifndef NetworkMenu_h
#define NetworkMenu_h

// $Id: NetworkMenu.h,v 1.14 2014/09/12 08:43:12 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Counter.h"

#include <QMenu>
#include <QAction>
#include <QString>
#include <QHash>

namespace Network
{

    /*!
    \class NetworkMenu
    \brief customized popup menu to open a previous logbook
    */
    class NetworkMenu: public QMenu, public Counter
    {

        //! Qt meta object declaration
        Q_OBJECT

        public:

        //! constructor
        NetworkMenu( const QString& = tr( "Select Network Device" ), QWidget* = 0 );

        //! destructor
        virtual ~NetworkMenu( void )
        {}

        //!@name modifiers
        //@{

        //! selected network name
        virtual void setDevice( const QString& value )
        { device_ = value; }

        //! select automatic selection
        virtual void setIsAutomatic( bool value )
        { isAutomatic_ = value; }

        Q_SIGNALS:

        //! signal emited when automatic device selection is triggered
        void automaticDeviceSelected( void );

        //! signal emited when a device is selected
        void deviceSelected( QString );

        private Q_SLOTS:

        //! select network
        void _select( QAction* );

        //! load list of network devices and update
        void _update( void );

        private:

        //! selected device
        QString device_;

        //! true if automatic is selected
        bool isAutomatic_;

        //! automation action
        QAction* automaticAction_;

        // action group
        QActionGroup* actionGroup_;

        //! map actions to file recors
        using ActionMap = QHash<QAction*, QString>;

        //! map actions to FileRecords
        ActionMap actions_;

    };

};

#endif
