#ifndef PictureWidget_h
#define PictureWidget_h
// $Id: PictureWidget.h,v 1.20 2014/09/12 08:43:12 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "TransparentWindow.h"
#include "PictureAttributes.h"

#include <QAction>
#include <QTimerEvent>
#include <QList>

//! clock widgets
namespace Pictures
{


    //! transparent clock widget
    class PictureWidget: public TransparentWindow
    {

        //! Qt meta object declaration
        Q_OBJECT

        public:

        //! window list
        using List = QList< PictureWidget* >;

        //! constructor
        PictureWidget( QWidget *parent = 0, const PictureAttributes& attributes = PictureAttributes() );

        //! attributes
        void setAttributes( const PictureAttributes& );

        //! attributes
        const PictureAttributes& attributes( void ) const
        { return attributes_; }

        //! attributes
        PictureAttributes& attributes( void )
        { return attributes_; }

        //! true if valid
        bool isValid( void ) const
        { return !truePixmap_.isNull(); }

        //! used to retrieve widget at a given position
        class SamePositionFTor
        {
            public:

            //! constructor
            SamePositionFTor( const QPoint& position ):
                position_( position )
            {}

            //! predicate
            bool operator () ( const PictureWidget* widget ) const
            { return widget->attributes().position() == position_; }

            //! predicate
            bool operator () ( const PictureAttributes& attributes ) const
            { return attributes.position() == position_; }

            private:

            //! predicted position
            QPoint position_;

        };

        Q_SIGNALS:

        //! emmited when hiding
        void pictureHidden( void );

        public Q_SLOTS:

        //! set size to match true image
        void adjustSizeToImage( void );

        protected:

        //! context menu
        virtual void _installContextMenuActions( BaseContextMenu* );

        //!@name event handlers
        //@{

        //! enter event
        /*! on enter event, the widget is set as active, to allow tooltip to be displayed */
        virtual void enterEvent( QEvent* );

        //! drag enter event
        virtual void dragEnterEvent( QDragEnterEvent* );

        //! drop event
        virtual void dropEvent( QDropEvent* );

        //! double click event
        virtual void mouseDoubleClickEvent( QMouseEvent* );

        //! timer event, to toggle repaint
        virtual void timerEvent( QTimerEvent* );

        //! paint event handler
        void _paint( QPaintDevice&, const QRect& );

        //@}

        //!@name actions
        //@{

        //! remove picture action
        QAction& _removePictureAction( void ) const
        { return *removePictureAction_; }

        //! change picture action
        QAction& _changePictureAction( void ) const
        { return *changePictureAction_; }

        //! close
        QAction& _closeAction( void ) const
        { return *closeAction_; }

        //@}

        protected Q_SLOTS:

        //! configuration
        virtual void _configuration( void );

        //! update configuration
        virtual void _updateConfiguration( void );

        //! remove picture
        virtual void _removePicture( void );

        //! change picture
        virtual void _changePicture( void );

        //! toggle aspect ratio
        virtual void _toggleKeepAspectRatio( bool );

        //! toggle filename
        virtual void _toggleShowFilename( bool );

        //! hide
        virtual void _hide( void );

        private:

        //! set image
        bool _updatePicture( void );

        //! install actions
        void _installActions( void );

        //! paint filename
        void _paintFilename( QPaintDevice&, const QRect&, bool shadow );

        //! paint empty frame
        void _paintEmpty( QPaintDevice&, const QRect&, bool shadow );

        //! scale image
        void _scale( void );

        //!@name actions
        //@{

        //! remove
        QAction* removePictureAction_;

        //! change
        QAction* changePictureAction_;

        //! close action
        QAction* closeAction_;

        //@}

        //!@name properties
        //@{

        //! filename
        PictureAttributes attributes_;

        //! true image
        QPixmap truePixmap_;

        //! scaled image
        QPixmap scaledPixmap_;

        //@}

    };



};

#endif
