// $Id: SummaryData.cpp,v 1.9 2015/01/08 20:03:50 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "SummaryData.h"
#include "QtUtil.h"
#include "TextFormat.h"

namespace Summary
{

    static const unsigned int spacing( 3 );
    static const unsigned int separator( 4 );

    //_______________________________________________________
    int SummaryData::valueExtend( QPainter& painter ) const
    {
        if( isSeparator_ || value_.isEmpty() ) return 0;

        painter.save();
        if( format_ )
        {

            QFont font( painter.font() );
            font.setWeight( (format_ & Format::Bold) ?  QFont::Bold:QFont::Normal );
            font.setItalic( format_ & Format::Italic );
            font.setUnderline( format_ & Format::Underline );
            font.setStrikeOut( format_ & Format::Strike);
            painter.setFont( font );

        }

        if( isTitle_ )
        {
            QFont font( QtUtil::titleFont( painter.font() ) );
            painter.setFont( font );
        }

        int extend =  painter.boundingRect( QRect(), Qt::AlignLeft|Qt::AlignTop, value_ ).width();
        painter.restore();
        return extend;

    }

    //_______________________________________________________
    int SummaryData::keyExtend( QPainter& painter ) const
    {
        if( isSeparator_ || key_.isEmpty() ) return 0;
        return painter.boundingRect( QRect(), Qt::AlignLeft|Qt::AlignTop, key_ + ": " ).width();
    }

    //_______________________________________________________
    void SummaryData::paint( QPainter& painter, QRect& rect ) const
    {

        if( isSeparator_ )
        {

            rect.setTop( rect.top() + separator );

        } else {

            painter.save();
            const int left( rect.left() );
            rect.setLeft( rect.left() + horizontalOffset_ );

            QRect boundingRect;

            // paint key
            if( !key_.isEmpty() )
            {
                // paint key
                QString buffer( key_ );
                if( !value_.isEmpty() ) buffer += ": ";

                // adjust color
                const QColor oldColor( painter.pen().color() );
                QColor color( oldColor );
                color.setAlpha( 0.8*color.alpha() );
                painter.setPen( color );

                // draw text
                painter.drawText( rect, Qt::AlignLeft|Qt::AlignTop, buffer, &boundingRect );

                // restore
                painter.setPen( oldColor );

                // update rect
                rect.setRight( qMax( rect.right(), boundingRect.right() ) );
                rect.setLeft( boundingRect.right() + spacing );
            }

            if( !value_.isEmpty() )
            {

                // paint value
                if( format_ )
                {

                    QFont font( painter.font() );
                    font.setWeight( (format_ & Format::Bold) ?  QFont::Bold:QFont::Normal );
                    font.setItalic( format_ & Format::Italic );
                    font.setUnderline( format_ & Format::Underline );
                    font.setStrikeOut( format_ & Format::Strike);
                    painter.setFont( font );

                }

                if( isTitle_ )
                {
                    QFont font( QtUtil::titleFont( painter.font() ) );
                    painter.setFont( font );
                }

                if( key_.isEmpty() )
                {

                    painter.drawText( rect, Qt::AlignHCenter|Qt::AlignTop, value_, &boundingRect );

                } else {

                    painter.drawText( rect, Qt::AlignLeft|Qt::AlignTop, value_, &boundingRect );

                }
            }

            // update rect
            rect.setRight( qMax( rect.right(), boundingRect.right() ) );
            rect.setTop( boundingRect.bottom() + spacing );
            rect.setLeft( left );

            painter.restore();

        }

        return;

    }


    //_______________________________________________________
    void SummaryDataList::paint( QPainter& painter, QRect& rect )
    {

        // calculate max extend
        int maxValueExtend(0);
        int maxKeyExtend(0);
        for( iterator iter = begin(); iter != end(); ++iter )
        {
            iter->setHorizontalOffset( iter->keyExtend( painter ) );
            maxKeyExtend = qMax( maxKeyExtend, iter->horizontalOffset() );
            maxValueExtend = qMax( maxValueExtend, iter->valueExtend( painter ) );
        }

        // set offsets
        for( iterator iter = begin(); iter != end(); ++iter )
        { iter->setHorizontalOffset( ( rect.width() + maxKeyExtend - maxValueExtend )/2 - iter->horizontalOffset() ); }

        // paint
        foreach( const SummaryData& data, *this )
        { data.paint( painter, rect ); }

    }

}
